==> cms-db_v0.9.tar.gz: admin/locales/de/locale_pages.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['pages'] = array();

$locale['pages']['link_editpage'] = 'Bearbeiten';
$locale['pages']['link_visibility'] = 'Sichtbarkeit';
$locale['pages']['link_newpage'] = 'Neu';
$locale['pages']['link_renamepage'] = 'Umbenennen';
$locale['pages']['link_deletepage'] = 'Löschen';
$locale['pages']['link_sortpages'] = 'Sortieren';
$locale['pages']['link_attributes'] = 'Attribute';
$locale['pages']['desc_saved'] = 'Die Seite %s wurde erfolgreich gespeichert!';
$locale['pages']['link_hide-all'] = 'Alle verbergen';
$locale['pages']['title_visibility'] = 'Sichtbarkeit der Seiten im Menü';
$locale['pages']['desc_visibility'] = 'Unsichtbare Seiten werden rot angezeigt. Die Startseite ("Home") kann nicht unsichtbar gemacht werden. In anderen Teilen des CMS werden unsichtbare Seiten durch die Endung DEL kenntlich gemacht.';
$locale['pages']['title_new'] = 'Neue Seite erstellen';
$locale['pages']['desc_new'] = 'Wo soll die neue Seite erstellt werden?';
$locale['pages']['desc_new-error-name'] = 'Sie müssen einen Namen für die Seite eingeben.';
$locale['pages']['desc_new-error'] = 'Die neue Seite kann nicht erstellt werden.';
$locale['pages']['desc_new-error-count'] = 'Sie können in dieser Seite keine weiteren Unterseiten anlegen.';
$locale['pages']['title_rename'] = 'Seite umbenennen';
$locale['pages']['button_rename'] = 'Umbenennen';
$locale['pages']['title_delete'] = 'Seite löschen';
$locale['pages']['title_sort'] = 'Seitensortierung';
$locale['pages']['desc_sort'] = 'Bitte wählen Sie eine Seite, deren Unterseiten sortiert werden sollen.';
$locale['pages']['desc_sort-manually'] = 'Von Hand sortieren';
$locale['pages']['desc_sort-alphabetically'] = 'Alphabetisch sortieren';
$locale['pages']['desc_sort-no-pages'] = 'Diese Seite besitzt keine sortierbaren Unterseiten.';
$locale['pages']['desc_sort-nojs'] = 'Zur Sortierung von Seiten wird Javascript benötigt.';
$locale['pages']['desc_sort-renamed'] = 'Umbenannt:';
$locale['pages']['desc_sort-urlindex'] = 'URL-Index aktualisiert';
$locale['pages']['desc_sort-error'] = 'Bei der Sortierung trat ein Fehler auf.';
$locale['pages']['title_attributes'] = 'Seitenattribute';
$locale['pages']['link_editattr'] = 'Bearbeiten';
$locale['pages']['link_addattr'] = 'Hinzufügen';
$locale['pages']['title_editattr'] = 'Attribute bearbeiten';
$locale['pages']['desc_delete-attr'] = 'Attribute können durch Löschen des Textes im dazugehörigen Eingabefeld entfernt werden.';
$locale['pages']['label_attr-meta'] = 'Meta-Tag "%s"';
$locale['pages']['label_attr-custom'] = 'Benutzerdefiniertes Attribut "%s"';
$locale['pages']['desc_comma-separated'] = '(getrennt durch Kommas)';
$locale['pages']['desc_no-attr'] = 'Es gibt keine Attribute für diese Seite.';
$locale['pages']['title_addattr'] = 'Attribut hinzufügen';
$locale['pages']['desc_save-before-adding'] = 'Bitte speichern Sie Änderungen an den bestehenden Attributen, bevor Sie ein neues hinzufügen!';
$locale['pages']['title_attr-meta'] = 'Meta-Tag';
$locale['pages']['label_attr-meta-type'] = 'Typ:';
$locale['pages']['title_attr-custom'] = 'Benutzerdefiniertes Attribut';
$locale['pages']['label_attr-custom-identifier'] = 'Bezeichnung:';
$locale['pages']['button_add'] = 'Hinzufügen';

==> cms-db_v0.9.3.tar.gz: admin/locales/de/locale_pages.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['pages'] = array();

$locale['pages']['desc_recyclebin'] = 'Durch Klick auf "löschen" werden Seiten in das Recycling-Center verschoben.';
$locale['pages']['link_newpage-toplevel'] = 'Neue übergeordnete Seite';
$locale['pages']['link_sortpages-toplevel'] = 'Übergeordnete Seiten sortieren';
$locale['pages']['desc_hidden'] = 'Versteckt';
$locale['pages']['link_editpage'] = 'bearbeiten';
$locale['pages']['link_visibility-on'] = 'im Menü zeigen';
$locale['pages']['link_visibility-off'] = 'im Menü verstecken';
$locale['pages']['link_newpage'] = 'Unterseite erstellen';
$locale['pages']['link_renamepage'] = 'umbenennen';
$locale['pages']['link_deletepage'] = 'löschen';
$locale['pages']['link_sortpages'] = 'Unterseiten sortieren';
$locale['pages']['link_attributes'] = 'Attribute ändern';
$locale['pages']['desc_saved'] = 'Die Seite %s wurde erfolgreich gespeichert!';
$locale['pages']['title_new'] = 'Neue Seite erstellen';
$locale['pages']['desc_new-subpage'] = 'Dies wird eine neue Unterseite in <i>%s</i> erstellen.';
$locale['pages']['desc_new-toplevel'] = 'Dies wird eine neue übergeordnete Seite erstellen.';
$locale['pages']['desc_new-error-name'] = 'Sie müssen einen Namen für die Seite eingeben.';
$locale['pages']['desc_new-error'] = 'Die neue Seite kann nicht erstellt werden.';
$locale['pages']['desc_new-error-count'] = 'Sie können in dieser Seite keine weiteren Unterseiten anlegen.';
$locale['pages']['title_rename'] = 'Seite umbenennen';
$locale['pages']['desc_rename'] = 'Seite <i>%s</i> umbenennen in:';
$locale['pages']['button_rename'] = 'Umbenennen';
$locale['pages']['title_sort'] = 'Seitensortierung';
$locale['pages']['desc_sort'] = 'Bitte wählen Sie eine Seite, deren Unterseiten sortiert werden sollen.';
$locale['pages']['desc_sort-manually'] = 'Von Hand sortieren';
$locale['pages']['desc_sort-alphabetically'] = 'Alphabetisch sortieren';
$locale['pages']['desc_sort-no-pages'] = 'Diese Seite besitzt keine sortierbaren Unterseiten.';
$locale['pages']['desc_sort-nojs'] = 'Zur Sortierung von Seiten wird Javascript benötigt.';
$locale['pages']['desc_sort-renamed'] = 'Umbenannt:';
$locale['pages']['desc_sort-urlindex'] = 'URL-Index aktualisiert';
$locale['pages']['desc_sort-error'] = 'Bei der Sortierung trat ein Fehler auf.';
$locale['pages']['title_attributes'] = 'Seitenattribute';
$locale['pages']['link_editattr'] = 'Bearbeiten';
$locale['pages']['link_addattr'] = 'Hinzufügen';
$locale['pages']['title_editattr'] = 'Attribute bearbeiten';
$locale['pages']['desc_delete-attr'] = 'Attribute können durch Löschen des Textes im dazugehörigen Eingabefeld entfernt werden.';
$locale['pages']['label_attr-meta'] = 'Meta-Tag "%s"';
$locale['pages']['label_attr-custom'] = 'Benutzerdefiniertes Attribut "%s"';
$locale['pages']['desc_comma-separated'] = '(getrennt durch Kommas)';
$locale['pages']['desc_no-attr'] = 'Es gibt keine Attribute für diese Seite.';
$locale['pages']['title_addattr'] = 'Attribut hinzufügen';
$locale['pages']['desc_save-before-adding'] = 'Bitte speichern Sie Änderungen an den bestehenden Attributen, bevor Sie ein neues hinzufügen!';
$locale['pages']['title_attr-meta'] = 'Meta-Tag';
$locale['pages']['label_attr-meta-type'] = 'Typ:';
$locale['pages']['title_attr-custom'] = 'Benutzerdefiniertes Attribut';
$locale['pages']['label_attr-custom-identifier'] = 'Bezeichnung:';
$locale['pages']['button_add'] = 'Hinzufügen';
